@@ -19,15 +19,13 @@ Current limitations:
   [ERROR]:   Didn't find any valid dependency graphs.
   [ERROR]:   This means that some of your requirements pull in conflicting dependencies.
 - only rebuilds on sdl2 bootstrap
-- supports mainly python3 with fallback to python2
 """
 import sh
 import os
 from pythonforandroid.build import Context
 from pythonforandroid import logger
-from pythonforandroid.graph import get_recipe_order_and_bootstrap
 from pythonforandroid.toolchain import current_directory
-from pythonforandroid.util import BuildInterruptingException
+from pythonforandroid.recipe import Recipe
 from ci.constants import TargetPython, CORE_RECIPES, BROKEN_RECIPES
 
 
@@ -54,19 +52,16 @@ def build(target_python, requirements):
     """
     if not requirements:
         return
-    testapp = 'setup_testapp_python2.py'
     android_sdk_home = os.environ['ANDROID_SDK_HOME']
     android_ndk_home = os.environ['ANDROID_NDK_HOME']
-    if target_python == TargetPython.python3:
-        testapp = 'setup_testapp_python3_sqlite_openssl.py'
     requirements.add(target_python.name)
     requirements = ','.join(requirements)
     logger.info('requirements: {}'.format(requirements))
-    with current_directory('testapps/'):
+    with current_directory('testapps/on_device_unit_tests/'):
         # iterates to stream the output
         for line in sh.python(
-                testapp, 'apk', '--sdk-dir', android_sdk_home,
-                '--ndk-dir', android_ndk_home, '--bootstrap', 'sdl2', '--requirements',
+                'setup.py', 'apk', '--sdk-dir', android_sdk_home,
+                '--ndk-dir', android_ndk_home, '--requirements',
                 requirements, _err_to_out=True, _iter=True):
             print(line)
 
@@ -78,16 +73,18 @@ def main():
     recipes -= CORE_RECIPES
     logger.info('recipes to build: {}'.format(recipes))
     context = Context()
-    # forces the default target
-    recipes_and_target = recipes | set([target_python.name])
-    try:
-        build_order, python_modules, bs = get_recipe_order_and_bootstrap(
-            context, recipes_and_target, None)
-    except BuildInterruptingException:
-        # fallback to python2 if default target is not compatible
-        logger.info('incompatible with {}'.format(target_python.name))
-        target_python = TargetPython.python2
-        logger.info('falling back to {}'.format(target_python.name))
+
+    # removing the deleted recipes for the given target (if any)
+    for recipe_name in recipes.copy():
+        try:
+            Recipe.get_recipe(recipe_name, context)
+        except ValueError:
+            # recipe doesn't exist, so probably we remove it
+            recipes.remove(recipe_name)
+            logger.warning(
+                'removed {} from recipes because deleted'.format(recipe_name)
+            )
+
     # removing the known broken recipe for the given target
     broken_recipes = BROKEN_RECIPES[target_python]
     recipes -= broken_recipes
