@@ -1,26 +1,23 @@
-from pythonforandroid.recipe import NDKRecipe
+from pythonforandroid.recipe import Recipe
 from pythonforandroid.toolchain import current_directory, shprint
-from os.path import join
 import sh
 
 
-class OggRecipe(NDKRecipe):
+class OggRecipe(Recipe):
     version = '1.3.3'
     url = 'http://downloads.xiph.org/releases/ogg/libogg-{version}.tar.gz'
-
-    generated_libraries = ['libogg.so']
+    built_libraries = {'libogg.so': 'src/.libs'}
 
     def build_arch(self, arch):
         with current_directory(self.get_build_dir(arch.arch)):
             env = self.get_recipe_env(arch)
             flags = [
-                '--with-sysroot=' + self.ctx.ndk_platform,
-                '--host=' + arch.toolchain_prefix,
+                '--with-sysroot=' + arch.ndk_platform,
+                '--host=' + arch.command_prefix,
             ]
             configure = sh.Command('./configure')
             shprint(configure, *flags, _env=env)
             shprint(sh.make, _env=env)
-            self.install_libs(arch, join('src', '.libs', 'libogg.so'))
 
 
 recipe = OggRecipe()
