@@ -6,9 +6,7 @@ from os.path import join
 
 
 class PyjniusRecipe(CythonRecipe):
-    # "6553ad4" is one commit after last release (1.2.0)
-    # it fixes method resolution, required for resolving requestPermissions()
-    version = '6553ad4'
+    version = '1.3.0'
     url = 'https://github.com/kivy/pyjnius/archive/{version}.zip'
     name = 'pyjnius'
     depends = [('genericndkbuild', 'sdl2'), 'six']
@@ -18,7 +16,7 @@ class PyjniusRecipe(CythonRecipe):
                ('genericndkbuild_jnienv_getter.patch', will_build('genericndkbuild'))]
 
     def postbuild_arch(self, arch):
-        super(PyjniusRecipe, self).postbuild_arch(arch)
+        super().postbuild_arch(arch)
         info('Copying pyjnius java class to classes build dir')
         with current_directory(self.get_build_dir(arch.arch)):
             shprint(sh.cp, '-a', join('jnius', 'src', 'org'), self.ctx.javaclass_dir)
