@@ -1,3 +1,5 @@
+from os.path import exists, join
+
 from pythonforandroid.recipe import BootstrapNDKRecipe
 from pythonforandroid.toolchain import current_directory, shprint
 import sh
@@ -11,21 +13,28 @@ class LibSDL2Recipe(BootstrapNDKRecipe):
     dir_name = 'SDL'
 
     depends = ['sdl2_image', 'sdl2_mixer', 'sdl2_ttf']
-    conflicts = ['sdl', 'pygame', 'pygame_bootstrap_components']
-
-    patches = ['add_nativeSetEnv.patch']
 
     def get_recipe_env(self, arch=None, with_flags_in_cc=True, with_python=True):
-        env = super(LibSDL2Recipe, self).get_recipe_env(
+        env = super().get_recipe_env(
             arch=arch, with_flags_in_cc=with_flags_in_cc, with_python=with_python)
         env['APP_ALLOW_MISSING_DEPS'] = 'true'
         return env
 
+    def should_build(self, arch):
+        libdir = join(self.get_build_dir(arch.arch), "../..", "libs", arch.arch)
+        libs = ['libhidapi.so', 'libmain.so', 'libSDL2.so', 'libSDL2_image.so', 'libSDL2_mixer.so', 'libSDL2_ttf.so']
+        return not all(exists(join(libdir, x)) for x in libs)
+
     def build_arch(self, arch):
         env = self.get_recipe_env(arch)
 
         with current_directory(self.get_jni_dir()):
-            shprint(sh.ndk_build, "V=1", _env=env)
+            shprint(
+                sh.ndk_build,
+                "V=1",
+                "NDK_DEBUG=" + ("1" if self.ctx.build_as_debuggable else "0"),
+                _env=env
+            )
 
 
 recipe = LibSDL2Recipe()
